@@ -5,6 +5,7 @@ from rezbuild.builder import InstallBuilder
 from rezbuild.builder import MacOSBuilder
 from rezbuild.builder import MacOSDmgBuilder
 from rezbuild.builder import PythonBuilder
+from rezbuild.builder import PythonSourceArchiveBuilder
 from rezbuild.builder import PythonSourceBuilder
 from rezbuild.builder import PythonWheelBuilder
 from rezbuild.builder import RezBuilder
@@ -17,6 +18,7 @@ __all__ = [
     "MacOSBuilder",
     "MacOSDmgBuilder",
     "PythonBuilder",
+    "PythonSourceArchiveBuilder",
     "PythonSourceBuilder",
     "PythonWheelBuilder",
     "RezBuilder",
